pub struct MessageInteractionMetadataApiType {
pub id: String,
pub type_: u8,
pub user: UserApiType,
pub authorizing_integration_owners: HashMap<ApplicationIntegrationTypesApiType, String>,
pub original_response_message_id: Option<String>,
pub target_user: Option<UserApiType>,
pub target_message_id: Option<String>,
pub interacted_message_id: Option<String>,
}Expand description
Fields
id: StringID of the interaction
type_: u8Type of interaction
user: UserApiTypeUser who triggered the interaction
IDs for installation context(s) related to an interaction Mapping of installation contexts that the interaction was authorized for to related user or guild IDs Keys are ApplicationIntegrationTypes (GUILD_INSTALL = 0, USER_INSTALL = 1) Values are snowflake IDs (guild ID for GUILD_INSTALL, user ID for USER_INSTALL, or “0” for DMs with bot)
original_response_message_id: Option<String>ID of the original response message, present only on follow-up messages
target_user: Option<UserApiType>The user the command was run on, present only on user command interactions
target_message_id: Option<String>The message the command was run on, present only on message command interactions
interacted_message_id: Option<String>ID of the message that contained interactive component, present only on messages created from component interactions