#[repr(u8)]pub enum DefaultMessageNotificationLevel {
ALL_MESSAGES = 0,
ONLY_MENTIONS = 1,
}Expand description
Variants
ALL_MESSAGES = 0
members will receive notifications for all messages by default
ONLY_MENTIONS = 1
members will receive notifications only for messages that @mention them by default