pub struct SoundboardSoundApiType {
pub name: String,
pub sound_id: String,
pub volume: f64,
pub emoji_id: Option<String>,
pub emoji_name: Option<String>,
pub guild_id: Option<String>,
pub available: bool,
pub user: Option<UserApiType>,
}Fields
name: Stringthe name of this sound
sound_id: Stringthe id of this sound
volume: f64the volume of this sound, from 0 to 1
emoji_id: Option<String>the id of this sound’s custom emoji
emoji_name: Option<String>the unicode character of this sound’s standard emoji
guild_id: Option<String>the id of the guild this sound is in
available: boolwhether this sound can be used, may be false due to loss of Server Boosts
user: Option<UserApiType>the user who created this sound